@@ -21,14 +21,8 @@ class Tabs(object):
             <li><a href="#tab2">The second</a></li>
         </ul>
         <div id="tab1">...
-            <div>
-              <label class="field_req" for="Tab1--title">title</label>
-              <input id="Tab1--title" name="Tab1--title" type="text" />
-            </div>...
-            <input type="submit" name="tab1" />
         </div>
         <div id="tab2">...
-            <input type="submit" name="tab2" />
         </div>
         </div>
         <script type="text/javascript">
@@ -37,7 +31,7 @@ class Tabs(object):
         <BLANKLINE>
             
     """
-    template = templates.get_template('tabs.mako')
+    template = templates.get_template('/forms/tabs.mako')
     def __init__(self, id, *fieldsets, **options):
         if not isinstance(id, basestring):
             raise TypeError('id must be a string. got %r' % (id,))
@@ -124,4 +118,4 @@ class Accordion(Tabs):
     """Work like :class:`~fa.jquery.forms.Tabs` but use
     http://jqueryui.com/demos/accordion/
     """
-    template = templates.get_template('accordion.mako')
+    template = templates.get_template('/forms/accordion.mako')
